from distutils.core import setup
setup(
    name = 'nester_s',
    version = '1.0.0',
    py_modules= ['nester_s'],
    author = 'Tyzx',
    author_email = 'zstu_xd1110@163.com',
    url = 'http://blog.csdn.net/qq_40766258',
    description = 'A simple printer of nested lists',
    )
